==> haskell-dns-3.0.4-87-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 3.0.4
id: dns-3.0.4-7XoIJZNvhD9KlOqdX5HGRc
key: dns-3.0.4-7XoIJZNvhD9KlOqdX5HGRc
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
abi: 26fe105736bcb10979225256fe8c4a89
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils
hidden-modules: Network.DNS.Decode.Internal Network.DNS.Imports
                Network.DNS.Memo Network.DNS.StateBinary Network.DNS.Transport
                Network.DNS.Types.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/dns-3.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/dns-3.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/dns-3.0.4
hs-libraries: HSdns-3.0.4-7XoIJZNvhD9KlOqdX5HGRc
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi
    auto-update-0.1.6-CUOKBxdInHjJLT0ZnWWA3x base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz binary-0.8.6.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    iproute-1.7.7-H1PvQD4fsqSF5DZuimogPc mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    psqueues-0.2.7.2-2G4cd8kkXaXI1aGbxwVq8H
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-3.0.4-88-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 3.0.4
id: dns-3.0.4-5CgBX3ZwdtaDEXeSSj5t9D
key: dns-3.0.4-5CgBX3ZwdtaDEXeSSj5t9D
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
abi: 0b41512542c7f7796f3e873e00caade2
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils
hidden-modules: Network.DNS.Decode.Internal Network.DNS.Imports
                Network.DNS.Memo Network.DNS.StateBinary Network.DNS.Transport
                Network.DNS.Types.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/dns-3.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/dns-3.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/dns-3.0.4
hs-libraries: HSdns-3.0.4-5CgBX3ZwdtaDEXeSSj5t9D
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi
    auto-update-0.1.6-6HwoHb0UkWSDuW69IvZChU base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz binary-0.8.6.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    iproute-1.7.7-H1PvQD4fsqSF5DZuimogPc mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    psqueues-0.2.7.2-2G4cd8kkXaXI1aGbxwVq8H
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
